@@ -5,11 +5,11 @@
 //           This file provides an SIMD version of the functions.
 // Language: C
 // Date:     01-May-2017
-// Ver:      24-Sep-2017.
+// Ver:      19-Jun-2018.
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2017    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2018    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -32,7 +32,9 @@
 
 #include "Python.h"
 
-#include "arrayfunc.h"
+#include "simddefs.h"
+#include "arrayops.h"
+
 #include "arrayerrs.h"
 
 /*--------------------------------------------------------------------------- */
@@ -75,7 +77,7 @@ signed int aall_signed_char_simd(signed int opcode, Py_ssize_t arraylen, signed
 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 			dataslice = (v16qi) __builtin_ia32_lddqu((char *) &data[index]);
@@ -95,7 +97,7 @@ signed int aall_signed_char_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return 1;
 
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 			dataslice = (v16qi) __builtin_ia32_lddqu((char *) &data[index]);
@@ -115,7 +117,7 @@ signed int aall_signed_char_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return 1;
 
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 			dataslice = (v16qi) __builtin_ia32_lddqu((char *) &data[index]);
@@ -136,7 +138,7 @@ signed int aall_signed_char_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return 1;
 
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 			dataslice = (v16qi) __builtin_ia32_lddqu((char *) &data[index]);
@@ -157,7 +159,7 @@ signed int aall_signed_char_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return 1;
 
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 			dataslice = (v16qi) __builtin_ia32_lddqu((char *) &data[index]);
@@ -177,7 +179,7 @@ signed int aall_signed_char_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return 1;
 
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
 			dataslice = (v16qi) __builtin_ia32_lddqu((char *) &data[index]);
@@ -239,7 +241,7 @@ signed int aall_signed_short_simd(signed int opcode, Py_ssize_t arraylen, signed
 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 			dataslice = (v8hi) __builtin_ia32_lddqu((char *) &data[index]);
@@ -259,7 +261,7 @@ signed int aall_signed_short_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return 1;
 
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 			dataslice = (v8hi) __builtin_ia32_lddqu((char *) &data[index]);
@@ -279,7 +281,7 @@ signed int aall_signed_short_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return 1;
 
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 			dataslice = (v8hi) __builtin_ia32_lddqu((char *) &data[index]);
@@ -300,7 +302,7 @@ signed int aall_signed_short_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return 1;
 
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 			dataslice = (v8hi) __builtin_ia32_lddqu((char *) &data[index]);
@@ -321,7 +323,7 @@ signed int aall_signed_short_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return 1;
 
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 			dataslice = (v8hi) __builtin_ia32_lddqu((char *) &data[index]);
@@ -341,7 +343,7 @@ signed int aall_signed_short_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return 1;
 
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
 			dataslice = (v8hi) __builtin_ia32_lddqu((char *) &data[index]);
@@ -403,7 +405,7 @@ signed int aall_signed_int_simd(signed int opcode, Py_ssize_t arraylen, signed i
 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
 			dataslice = (v4si) __builtin_ia32_lddqu((char *) &data[index]);
@@ -423,7 +425,7 @@ signed int aall_signed_int_simd(signed int opcode, Py_ssize_t arraylen, signed i
 		return 1;
 
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
 			dataslice = (v4si) __builtin_ia32_lddqu((char *) &data[index]);
@@ -443,7 +445,7 @@ signed int aall_signed_int_simd(signed int opcode, Py_ssize_t arraylen, signed i
 		return 1;
 
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
 			dataslice = (v4si) __builtin_ia32_lddqu((char *) &data[index]);
@@ -464,7 +466,7 @@ signed int aall_signed_int_simd(signed int opcode, Py_ssize_t arraylen, signed i
 		return 1;
 
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
 			dataslice = (v4si) __builtin_ia32_lddqu((char *) &data[index]);
@@ -485,7 +487,7 @@ signed int aall_signed_int_simd(signed int opcode, Py_ssize_t arraylen, signed i
 		return 1;
 
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
 			dataslice = (v4si) __builtin_ia32_lddqu((char *) &data[index]);
@@ -505,7 +507,7 @@ signed int aall_signed_int_simd(signed int opcode, Py_ssize_t arraylen, signed i
 		return 1;
 
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
 			dataslice = (v4si) __builtin_ia32_lddqu((char *) &data[index]);
@@ -567,7 +569,7 @@ signed int aall_float_simd(signed int opcode, Py_ssize_t arraylen, float *data,
 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
 			dataslice = (v4sf) __builtin_ia32_loadups(&data[index]);
@@ -587,7 +589,7 @@ signed int aall_float_simd(signed int opcode, Py_ssize_t arraylen, float *data,
 		return 1;
 
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
 			dataslice = (v4sf) __builtin_ia32_loadups(&data[index]);
@@ -607,7 +609,7 @@ signed int aall_float_simd(signed int opcode, Py_ssize_t arraylen, float *data,
 		return 1;
 
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
 			dataslice = (v4sf) __builtin_ia32_loadups(&data[index]);
@@ -627,7 +629,7 @@ signed int aall_float_simd(signed int opcode, Py_ssize_t arraylen, float *data,
 		return 1;
 
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
 			dataslice = (v4sf) __builtin_ia32_loadups(&data[index]);
@@ -647,7 +649,7 @@ signed int aall_float_simd(signed int opcode, Py_ssize_t arraylen, float *data,
 		return 1;
 
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
 			dataslice = (v4sf) __builtin_ia32_loadups(&data[index]);
@@ -667,7 +669,7 @@ signed int aall_float_simd(signed int opcode, Py_ssize_t arraylen, float *data,
 		return 1;
 
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
 			dataslice = (v4sf) __builtin_ia32_loadups(&data[index]);
@@ -729,7 +731,7 @@ signed int aall_double_simd(signed int opcode, Py_ssize_t arraylen, double *data
 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
 			dataslice = (v2df) __builtin_ia32_loadupd(&data[index]);
@@ -749,7 +751,7 @@ signed int aall_double_simd(signed int opcode, Py_ssize_t arraylen, double *data
 		return 1;
 
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
 			dataslice = (v2df) __builtin_ia32_loadupd(&data[index]);
@@ -769,7 +771,7 @@ signed int aall_double_simd(signed int opcode, Py_ssize_t arraylen, double *data
 		return 1;
 
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
 			dataslice = (v2df) __builtin_ia32_loadupd(&data[index]);
@@ -789,7 +791,7 @@ signed int aall_double_simd(signed int opcode, Py_ssize_t arraylen, double *data
 		return 1;
 
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
 			dataslice = (v2df) __builtin_ia32_loadupd(&data[index]);
@@ -809,7 +811,7 @@ signed int aall_double_simd(signed int opcode, Py_ssize_t arraylen, double *data
 		return 1;
 
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
 			dataslice = (v2df) __builtin_ia32_loadupd(&data[index]);
@@ -829,7 +831,7 @@ signed int aall_double_simd(signed int opcode, Py_ssize_t arraylen, double *data
 		return 1;
 
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
 			dataslice = (v2df) __builtin_ia32_loadupd(&data[index]);
