@@ -5,11 +5,11 @@
 //           Common platform independent code.
 // Language: C
 // Date:     08-May-2014
-// Ver:      24-Sep-2017.
+// Ver:      19-Jun-2018.
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2017    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2018    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -32,11 +32,13 @@
 
 #include "Python.h"
 
+#include "arrayparams_base.h"
+#include "arrayops.h"
+#include "simddefs.h"
 #ifdef AF_HASSIMD
 #include "aany_simd_x86.h"
 #endif
 
-#include "arrayfunc.h"
 #include "arrayerrs.h"
 
 /*--------------------------------------------------------------------------- */
@@ -68,7 +70,7 @@ signed int aany_signed_char(signed int opcode, Py_ssize_t arraylen, signed char
 #endif
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -77,7 +79,7 @@ signed int aany_signed_char(signed int opcode, Py_ssize_t arraylen, signed char
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -86,7 +88,7 @@ signed int aany_signed_char(signed int opcode, Py_ssize_t arraylen, signed char
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -95,7 +97,7 @@ signed int aany_signed_char(signed int opcode, Py_ssize_t arraylen, signed char
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -104,7 +106,7 @@ signed int aany_signed_char(signed int opcode, Py_ssize_t arraylen, signed char
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -113,7 +115,7 @@ signed int aany_signed_char(signed int opcode, Py_ssize_t arraylen, signed char
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -143,7 +145,7 @@ signed int aany_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsigned c
 	Py_ssize_t index; 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -152,7 +154,7 @@ signed int aany_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsigned c
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -161,7 +163,7 @@ signed int aany_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsigned c
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -170,7 +172,7 @@ signed int aany_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsigned c
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -179,7 +181,7 @@ signed int aany_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsigned c
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -188,7 +190,7 @@ signed int aany_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsigned c
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -226,7 +228,7 @@ signed int aany_signed_short(signed int opcode, Py_ssize_t arraylen, signed shor
 #endif
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -235,7 +237,7 @@ signed int aany_signed_short(signed int opcode, Py_ssize_t arraylen, signed shor
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -244,7 +246,7 @@ signed int aany_signed_short(signed int opcode, Py_ssize_t arraylen, signed shor
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -253,7 +255,7 @@ signed int aany_signed_short(signed int opcode, Py_ssize_t arraylen, signed shor
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -262,7 +264,7 @@ signed int aany_signed_short(signed int opcode, Py_ssize_t arraylen, signed shor
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -271,7 +273,7 @@ signed int aany_signed_short(signed int opcode, Py_ssize_t arraylen, signed shor
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -301,7 +303,7 @@ signed int aany_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsigned
 	Py_ssize_t index; 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -310,7 +312,7 @@ signed int aany_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsigned
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -319,7 +321,7 @@ signed int aany_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsigned
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -328,7 +330,7 @@ signed int aany_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsigned
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -337,7 +339,7 @@ signed int aany_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsigned
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -346,7 +348,7 @@ signed int aany_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsigned
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -384,7 +386,7 @@ signed int aany_signed_int(signed int opcode, Py_ssize_t arraylen, signed int *d
 #endif
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -393,7 +395,7 @@ signed int aany_signed_int(signed int opcode, Py_ssize_t arraylen, signed int *d
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -402,7 +404,7 @@ signed int aany_signed_int(signed int opcode, Py_ssize_t arraylen, signed int *d
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -411,7 +413,7 @@ signed int aany_signed_int(signed int opcode, Py_ssize_t arraylen, signed int *d
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -420,7 +422,7 @@ signed int aany_signed_int(signed int opcode, Py_ssize_t arraylen, signed int *d
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -429,7 +431,7 @@ signed int aany_signed_int(signed int opcode, Py_ssize_t arraylen, signed int *d
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -459,7 +461,7 @@ signed int aany_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsigned in
 	Py_ssize_t index; 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -468,7 +470,7 @@ signed int aany_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsigned in
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -477,7 +479,7 @@ signed int aany_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsigned in
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -486,7 +488,7 @@ signed int aany_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsigned in
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -495,7 +497,7 @@ signed int aany_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsigned in
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -504,7 +506,7 @@ signed int aany_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsigned in
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -534,7 +536,7 @@ signed int aany_signed_long(signed int opcode, Py_ssize_t arraylen, signed long
 	Py_ssize_t index; 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -543,7 +545,7 @@ signed int aany_signed_long(signed int opcode, Py_ssize_t arraylen, signed long
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -552,7 +554,7 @@ signed int aany_signed_long(signed int opcode, Py_ssize_t arraylen, signed long
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -561,7 +563,7 @@ signed int aany_signed_long(signed int opcode, Py_ssize_t arraylen, signed long
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -570,7 +572,7 @@ signed int aany_signed_long(signed int opcode, Py_ssize_t arraylen, signed long
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -579,7 +581,7 @@ signed int aany_signed_long(signed int opcode, Py_ssize_t arraylen, signed long
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -609,7 +611,7 @@ signed int aany_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsigned l
 	Py_ssize_t index; 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -618,7 +620,7 @@ signed int aany_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsigned l
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -627,7 +629,7 @@ signed int aany_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsigned l
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -636,7 +638,7 @@ signed int aany_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsigned l
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -645,7 +647,7 @@ signed int aany_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsigned l
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -654,7 +656,7 @@ signed int aany_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsigned l
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -684,7 +686,7 @@ signed int aany_signed_long_long(signed int opcode, Py_ssize_t arraylen, signed
 	Py_ssize_t index; 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -693,7 +695,7 @@ signed int aany_signed_long_long(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -702,7 +704,7 @@ signed int aany_signed_long_long(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -711,7 +713,7 @@ signed int aany_signed_long_long(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -720,7 +722,7 @@ signed int aany_signed_long_long(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -729,7 +731,7 @@ signed int aany_signed_long_long(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -759,7 +761,7 @@ signed int aany_unsigned_long_long(signed int opcode, Py_ssize_t arraylen, unsig
 	Py_ssize_t index; 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -768,7 +770,7 @@ signed int aany_unsigned_long_long(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -777,7 +779,7 @@ signed int aany_unsigned_long_long(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -786,7 +788,7 @@ signed int aany_unsigned_long_long(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -795,7 +797,7 @@ signed int aany_unsigned_long_long(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -804,7 +806,7 @@ signed int aany_unsigned_long_long(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -842,7 +844,7 @@ signed int aany_float(signed int opcode, Py_ssize_t arraylen, float *data, float
 #endif
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -851,7 +853,7 @@ signed int aany_float(signed int opcode, Py_ssize_t arraylen, float *data, float
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -860,7 +862,7 @@ signed int aany_float(signed int opcode, Py_ssize_t arraylen, float *data, float
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -869,7 +871,7 @@ signed int aany_float(signed int opcode, Py_ssize_t arraylen, float *data, float
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -878,7 +880,7 @@ signed int aany_float(signed int opcode, Py_ssize_t arraylen, float *data, float
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -887,7 +889,7 @@ signed int aany_float(signed int opcode, Py_ssize_t arraylen, float *data, float
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -925,7 +927,7 @@ signed int aany_double(signed int opcode, Py_ssize_t arraylen, double *data, dou
 #endif
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -934,7 +936,7 @@ signed int aany_double(signed int opcode, Py_ssize_t arraylen, double *data, dou
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -943,7 +945,7 @@ signed int aany_double(signed int opcode, Py_ssize_t arraylen, double *data, dou
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -952,7 +954,7 @@ signed int aany_double(signed int opcode, Py_ssize_t arraylen, double *data, dou
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -961,7 +963,7 @@ signed int aany_double(signed int opcode, Py_ssize_t arraylen, double *data, dou
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -970,7 +972,7 @@ signed int aany_double(signed int opcode, Py_ssize_t arraylen, double *data, dou
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
