@@ -5,11 +5,11 @@
 //           This file provides an SIMD version of the functions.
 // Language: C
 // Date:     01-May-2017
-// Ver:      24-Sep-2017.
+// Ver:      19-Jun-2018.
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2017    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2018    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -32,7 +32,9 @@
 
 #include "Python.h"
 
-#include "arrayfunc.h"
+#include "simddefs.h"
+#include "arrayops.h"
+
 #include "arrayerrs.h"
 
 /*--------------------------------------------------------------------------- */
@@ -75,7 +77,7 @@ signed int aany_signed_char_simd(signed int opcode, Py_ssize_t arraylen, signed
 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
@@ -96,7 +98,7 @@ signed int aany_signed_char_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
@@ -117,7 +119,7 @@ signed int aany_signed_char_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
@@ -139,7 +141,7 @@ signed int aany_signed_char_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
@@ -161,7 +163,7 @@ signed int aany_signed_char_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
@@ -182,7 +184,7 @@ signed int aany_signed_char_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
@@ -245,7 +247,7 @@ signed int aany_signed_short_simd(signed int opcode, Py_ssize_t arraylen, signed
 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
@@ -266,7 +268,7 @@ signed int aany_signed_short_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
@@ -287,7 +289,7 @@ signed int aany_signed_short_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
@@ -309,7 +311,7 @@ signed int aany_signed_short_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
@@ -331,7 +333,7 @@ signed int aany_signed_short_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
@@ -352,7 +354,7 @@ signed int aany_signed_short_simd(signed int opcode, Py_ssize_t arraylen, signed
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
@@ -415,7 +417,7 @@ signed int aany_signed_int_simd(signed int opcode, Py_ssize_t arraylen, signed i
 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
@@ -436,7 +438,7 @@ signed int aany_signed_int_simd(signed int opcode, Py_ssize_t arraylen, signed i
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
@@ -457,7 +459,7 @@ signed int aany_signed_int_simd(signed int opcode, Py_ssize_t arraylen, signed i
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
@@ -479,7 +481,7 @@ signed int aany_signed_int_simd(signed int opcode, Py_ssize_t arraylen, signed i
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
@@ -501,7 +503,7 @@ signed int aany_signed_int_simd(signed int opcode, Py_ssize_t arraylen, signed i
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
@@ -522,7 +524,7 @@ signed int aany_signed_int_simd(signed int opcode, Py_ssize_t arraylen, signed i
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
@@ -585,7 +587,7 @@ signed int aany_float_simd(signed int opcode, Py_ssize_t arraylen, float *data,
 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
@@ -606,7 +608,7 @@ signed int aany_float_simd(signed int opcode, Py_ssize_t arraylen, float *data,
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
@@ -627,7 +629,7 @@ signed int aany_float_simd(signed int opcode, Py_ssize_t arraylen, float *data,
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
@@ -648,7 +650,7 @@ signed int aany_float_simd(signed int opcode, Py_ssize_t arraylen, float *data,
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
@@ -669,7 +671,7 @@ signed int aany_float_simd(signed int opcode, Py_ssize_t arraylen, float *data,
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
@@ -690,7 +692,7 @@ signed int aany_float_simd(signed int opcode, Py_ssize_t arraylen, float *data,
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
@@ -753,7 +755,7 @@ signed int aany_double_simd(signed int opcode, Py_ssize_t arraylen, double *data
 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
@@ -774,7 +776,7 @@ signed int aany_double_simd(signed int opcode, Py_ssize_t arraylen, double *data
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
@@ -795,7 +797,7 @@ signed int aany_double_simd(signed int opcode, Py_ssize_t arraylen, double *data
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
@@ -816,7 +818,7 @@ signed int aany_double_simd(signed int opcode, Py_ssize_t arraylen, double *data
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
@@ -837,7 +839,7 @@ signed int aany_double_simd(signed int opcode, Py_ssize_t arraylen, double *data
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
@@ -858,7 +860,7 @@ signed int aany_double_simd(signed int opcode, Py_ssize_t arraylen, double *data
 		return ARR_ERR_NOTFOUND;
 
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		// Use SIMD.
 		for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
