@@ -5,11 +5,11 @@
 //           Common platform independent code.
 // Language: C
 // Date:     09-May-2014
-// Ver:      24-Sep-2017.
+// Ver:      19-Jun-2018.
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2017    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2018    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -32,7 +32,9 @@
 
 #include "Python.h"
 
-#include "arrayfunc.h"
+#include "arrayparams_base.h"
+#include "arrayops.h"
+
 #include "arrayerrs.h"
 
 /*--------------------------------------------------------------------------- */
@@ -60,7 +62,7 @@ Py_ssize_t afilter_signed_char(signed int opcode, Py_ssize_t arraylen, signed ch
 	outindex = 0;
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] == param1) {
@@ -70,7 +72,7 @@ Py_ssize_t afilter_signed_char(signed int opcode, Py_ssize_t arraylen, signed ch
 			}
 			return outindex;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] > param1) {
@@ -80,7 +82,7 @@ Py_ssize_t afilter_signed_char(signed int opcode, Py_ssize_t arraylen, signed ch
 			}
 			return outindex;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] >= param1) {
@@ -90,7 +92,7 @@ Py_ssize_t afilter_signed_char(signed int opcode, Py_ssize_t arraylen, signed ch
 			}
 			return outindex;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] < param1) {
@@ -100,7 +102,7 @@ Py_ssize_t afilter_signed_char(signed int opcode, Py_ssize_t arraylen, signed ch
 			}
 			return outindex;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] <= param1) {
@@ -110,7 +112,7 @@ Py_ssize_t afilter_signed_char(signed int opcode, Py_ssize_t arraylen, signed ch
 			}
 			return outindex;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] != param1) {
@@ -145,7 +147,7 @@ Py_ssize_t afilter_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsigne
 	outindex = 0;
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] == param1) {
@@ -155,7 +157,7 @@ Py_ssize_t afilter_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsigne
 			}
 			return outindex;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] > param1) {
@@ -165,7 +167,7 @@ Py_ssize_t afilter_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsigne
 			}
 			return outindex;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] >= param1) {
@@ -175,7 +177,7 @@ Py_ssize_t afilter_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsigne
 			}
 			return outindex;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] < param1) {
@@ -185,7 +187,7 @@ Py_ssize_t afilter_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsigne
 			}
 			return outindex;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] <= param1) {
@@ -195,7 +197,7 @@ Py_ssize_t afilter_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsigne
 			}
 			return outindex;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] != param1) {
@@ -230,7 +232,7 @@ Py_ssize_t afilter_signed_short(signed int opcode, Py_ssize_t arraylen, signed s
 	outindex = 0;
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] == param1) {
@@ -240,7 +242,7 @@ Py_ssize_t afilter_signed_short(signed int opcode, Py_ssize_t arraylen, signed s
 			}
 			return outindex;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] > param1) {
@@ -250,7 +252,7 @@ Py_ssize_t afilter_signed_short(signed int opcode, Py_ssize_t arraylen, signed s
 			}
 			return outindex;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] >= param1) {
@@ -260,7 +262,7 @@ Py_ssize_t afilter_signed_short(signed int opcode, Py_ssize_t arraylen, signed s
 			}
 			return outindex;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] < param1) {
@@ -270,7 +272,7 @@ Py_ssize_t afilter_signed_short(signed int opcode, Py_ssize_t arraylen, signed s
 			}
 			return outindex;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] <= param1) {
@@ -280,7 +282,7 @@ Py_ssize_t afilter_signed_short(signed int opcode, Py_ssize_t arraylen, signed s
 			}
 			return outindex;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] != param1) {
@@ -315,7 +317,7 @@ Py_ssize_t afilter_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsign
 	outindex = 0;
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] == param1) {
@@ -325,7 +327,7 @@ Py_ssize_t afilter_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsign
 			}
 			return outindex;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] > param1) {
@@ -335,7 +337,7 @@ Py_ssize_t afilter_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsign
 			}
 			return outindex;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] >= param1) {
@@ -345,7 +347,7 @@ Py_ssize_t afilter_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsign
 			}
 			return outindex;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] < param1) {
@@ -355,7 +357,7 @@ Py_ssize_t afilter_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsign
 			}
 			return outindex;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] <= param1) {
@@ -365,7 +367,7 @@ Py_ssize_t afilter_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsign
 			}
 			return outindex;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] != param1) {
@@ -400,7 +402,7 @@ Py_ssize_t afilter_signed_int(signed int opcode, Py_ssize_t arraylen, signed int
 	outindex = 0;
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] == param1) {
@@ -410,7 +412,7 @@ Py_ssize_t afilter_signed_int(signed int opcode, Py_ssize_t arraylen, signed int
 			}
 			return outindex;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] > param1) {
@@ -420,7 +422,7 @@ Py_ssize_t afilter_signed_int(signed int opcode, Py_ssize_t arraylen, signed int
 			}
 			return outindex;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] >= param1) {
@@ -430,7 +432,7 @@ Py_ssize_t afilter_signed_int(signed int opcode, Py_ssize_t arraylen, signed int
 			}
 			return outindex;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] < param1) {
@@ -440,7 +442,7 @@ Py_ssize_t afilter_signed_int(signed int opcode, Py_ssize_t arraylen, signed int
 			}
 			return outindex;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] <= param1) {
@@ -450,7 +452,7 @@ Py_ssize_t afilter_signed_int(signed int opcode, Py_ssize_t arraylen, signed int
 			}
 			return outindex;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] != param1) {
@@ -485,7 +487,7 @@ Py_ssize_t afilter_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsigned
 	outindex = 0;
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] == param1) {
@@ -495,7 +497,7 @@ Py_ssize_t afilter_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsigned
 			}
 			return outindex;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] > param1) {
@@ -505,7 +507,7 @@ Py_ssize_t afilter_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsigned
 			}
 			return outindex;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] >= param1) {
@@ -515,7 +517,7 @@ Py_ssize_t afilter_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsigned
 			}
 			return outindex;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] < param1) {
@@ -525,7 +527,7 @@ Py_ssize_t afilter_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsigned
 			}
 			return outindex;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] <= param1) {
@@ -535,7 +537,7 @@ Py_ssize_t afilter_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsigned
 			}
 			return outindex;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] != param1) {
@@ -570,7 +572,7 @@ Py_ssize_t afilter_signed_long(signed int opcode, Py_ssize_t arraylen, signed lo
 	outindex = 0;
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] == param1) {
@@ -580,7 +582,7 @@ Py_ssize_t afilter_signed_long(signed int opcode, Py_ssize_t arraylen, signed lo
 			}
 			return outindex;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] > param1) {
@@ -590,7 +592,7 @@ Py_ssize_t afilter_signed_long(signed int opcode, Py_ssize_t arraylen, signed lo
 			}
 			return outindex;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] >= param1) {
@@ -600,7 +602,7 @@ Py_ssize_t afilter_signed_long(signed int opcode, Py_ssize_t arraylen, signed lo
 			}
 			return outindex;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] < param1) {
@@ -610,7 +612,7 @@ Py_ssize_t afilter_signed_long(signed int opcode, Py_ssize_t arraylen, signed lo
 			}
 			return outindex;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] <= param1) {
@@ -620,7 +622,7 @@ Py_ssize_t afilter_signed_long(signed int opcode, Py_ssize_t arraylen, signed lo
 			}
 			return outindex;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] != param1) {
@@ -655,7 +657,7 @@ Py_ssize_t afilter_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsigne
 	outindex = 0;
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] == param1) {
@@ -665,7 +667,7 @@ Py_ssize_t afilter_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsigne
 			}
 			return outindex;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] > param1) {
@@ -675,7 +677,7 @@ Py_ssize_t afilter_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsigne
 			}
 			return outindex;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] >= param1) {
@@ -685,7 +687,7 @@ Py_ssize_t afilter_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsigne
 			}
 			return outindex;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] < param1) {
@@ -695,7 +697,7 @@ Py_ssize_t afilter_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsigne
 			}
 			return outindex;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] <= param1) {
@@ -705,7 +707,7 @@ Py_ssize_t afilter_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsigne
 			}
 			return outindex;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] != param1) {
@@ -740,7 +742,7 @@ Py_ssize_t afilter_signed_long_long(signed int opcode, Py_ssize_t arraylen, sign
 	outindex = 0;
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] == param1) {
@@ -750,7 +752,7 @@ Py_ssize_t afilter_signed_long_long(signed int opcode, Py_ssize_t arraylen, sign
 			}
 			return outindex;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] > param1) {
@@ -760,7 +762,7 @@ Py_ssize_t afilter_signed_long_long(signed int opcode, Py_ssize_t arraylen, sign
 			}
 			return outindex;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] >= param1) {
@@ -770,7 +772,7 @@ Py_ssize_t afilter_signed_long_long(signed int opcode, Py_ssize_t arraylen, sign
 			}
 			return outindex;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] < param1) {
@@ -780,7 +782,7 @@ Py_ssize_t afilter_signed_long_long(signed int opcode, Py_ssize_t arraylen, sign
 			}
 			return outindex;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] <= param1) {
@@ -790,7 +792,7 @@ Py_ssize_t afilter_signed_long_long(signed int opcode, Py_ssize_t arraylen, sign
 			}
 			return outindex;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] != param1) {
@@ -825,7 +827,7 @@ Py_ssize_t afilter_unsigned_long_long(signed int opcode, Py_ssize_t arraylen, un
 	outindex = 0;
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] == param1) {
@@ -835,7 +837,7 @@ Py_ssize_t afilter_unsigned_long_long(signed int opcode, Py_ssize_t arraylen, un
 			}
 			return outindex;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] > param1) {
@@ -845,7 +847,7 @@ Py_ssize_t afilter_unsigned_long_long(signed int opcode, Py_ssize_t arraylen, un
 			}
 			return outindex;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] >= param1) {
@@ -855,7 +857,7 @@ Py_ssize_t afilter_unsigned_long_long(signed int opcode, Py_ssize_t arraylen, un
 			}
 			return outindex;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] < param1) {
@@ -865,7 +867,7 @@ Py_ssize_t afilter_unsigned_long_long(signed int opcode, Py_ssize_t arraylen, un
 			}
 			return outindex;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] <= param1) {
@@ -875,7 +877,7 @@ Py_ssize_t afilter_unsigned_long_long(signed int opcode, Py_ssize_t arraylen, un
 			}
 			return outindex;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] != param1) {
@@ -910,7 +912,7 @@ Py_ssize_t afilter_float(signed int opcode, Py_ssize_t arraylen, float *data, fl
 	outindex = 0;
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] == param1) {
@@ -920,7 +922,7 @@ Py_ssize_t afilter_float(signed int opcode, Py_ssize_t arraylen, float *data, fl
 			}
 			return outindex;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] > param1) {
@@ -930,7 +932,7 @@ Py_ssize_t afilter_float(signed int opcode, Py_ssize_t arraylen, float *data, fl
 			}
 			return outindex;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] >= param1) {
@@ -940,7 +942,7 @@ Py_ssize_t afilter_float(signed int opcode, Py_ssize_t arraylen, float *data, fl
 			}
 			return outindex;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] < param1) {
@@ -950,7 +952,7 @@ Py_ssize_t afilter_float(signed int opcode, Py_ssize_t arraylen, float *data, fl
 			}
 			return outindex;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] <= param1) {
@@ -960,7 +962,7 @@ Py_ssize_t afilter_float(signed int opcode, Py_ssize_t arraylen, float *data, fl
 			}
 			return outindex;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] != param1) {
@@ -995,7 +997,7 @@ Py_ssize_t afilter_double(signed int opcode, Py_ssize_t arraylen, double *data,
 	outindex = 0;
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] == param1) {
@@ -1005,7 +1007,7 @@ Py_ssize_t afilter_double(signed int opcode, Py_ssize_t arraylen, double *data,
 			}
 			return outindex;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] > param1) {
@@ -1015,7 +1017,7 @@ Py_ssize_t afilter_double(signed int opcode, Py_ssize_t arraylen, double *data,
 			}
 			return outindex;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] >= param1) {
@@ -1025,7 +1027,7 @@ Py_ssize_t afilter_double(signed int opcode, Py_ssize_t arraylen, double *data,
 			}
 			return outindex;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] < param1) {
@@ -1035,7 +1037,7 @@ Py_ssize_t afilter_double(signed int opcode, Py_ssize_t arraylen, double *data,
 			}
 			return outindex;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] <= param1) {
@@ -1045,7 +1047,7 @@ Py_ssize_t afilter_double(signed int opcode, Py_ssize_t arraylen, double *data,
 			}
 			return outindex;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (data[index] != param1) {
