@@ -5,11 +5,11 @@
 //           This file provides an SIMD version of the functions.
 // Language: C
 // Date:     05-May-2017
-// Ver:      24-Sep-2017.
+// Ver:      19-Jun-2018.
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2017    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2018    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -32,7 +32,9 @@
 
 #include "Python.h"
 
-#include "arrayfunc.h"
+#include "simddefs.h"
+#include "arrayops.h"
+
 #include "arrayerrs.h"
 
 /*--------------------------------------------------------------------------- */
@@ -46,7 +48,7 @@
    arraylen = The length of the data array.
    data = The input data array.
    errflag = Set to true if an overflow error occured in integer operations.
-   disableovfl = If true, arithmetic overflow checking is disabled.
+   ignoreerrors = If true, arithmetic overflow checking is disabled.
    nosimd = If true, disable SIMD.
    Returns: The sum of the array.
 */
@@ -97,7 +99,7 @@ float asum_float_simd(Py_ssize_t arraylen, float *data) {
    arraylen = The length of the data array.
    data = The input data array.
    errflag = Set to true if an overflow error occured in integer operations.
-   disableovfl = If true, arithmetic overflow checking is disabled.
+   ignoreerrors = If true, arithmetic overflow checking is disabled.
    nosimd = If true, disable SIMD.
    Returns: The sum of the array.
 */
