@@ -30,9 +30,10 @@
 
 #include "Python.h"
 
-#include "arrayfunc.h"
+#include "arrayparams_base.h"
 #include "arrayerrs.h"
 
+#include "arrayops.h"
 #include "count_common.h"
 
 /*--------------------------------------------------------------------------- */
@@ -69,7 +70,7 @@ struct args_param parsepyargs_parm(PyObject *args) {
 
 
 	struct args_param argtypes = {' ', ' ', 0};
-	struct arrayparamstypes arr1type = {0, 0, ' '};
+	char arr1type;
 
 	/* Import the raw objects. */
 	if (!PyArg_ParseTuple(args, "OO|O:count", &dataobj, &param1obj, &param2obj)) {
@@ -78,13 +79,13 @@ struct args_param parsepyargs_parm(PyObject *args) {
 	}
 
 	// Test if the first parameter is an array or bytes.
-	arr1type = paramarraytype(dataobj);
-	if (!arr1type.isarray) {
+	arr1type = lookuparraycode(dataobj);
+	if (!arr1type) {
 		argtypes.error = 2;
 		return argtypes;
 	} else {
 		// Get the array code type character.
-		argtypes.array1type = arr1type.arraycode;
+		argtypes.array1type = arr1type;
 	}
 
 
@@ -93,9 +94,9 @@ struct args_param parsepyargs_parm(PyObject *args) {
 
 	// The third parameter is optional, so we have to test if it was set.
 	if (param2obj != NULL) {
-		argtypes.param2type = paramtypecode(param2obj->ob_type->tp_name);
+		argtypes.param2type = paramtypecode(param2obj);
 	} else {
-		argtypes.param2type = 'z';
+		argtypes.param2type = 0;
 	}
 
 
@@ -166,7 +167,7 @@ py_count(PyObject *self, PyObject *args)
 	itemcode = argtypes.array1type;
 
 	// The second parameter (step) was not specified.
-	if (argtypes.param2type == 'z') {
+	if (!argtypes.param2type) {
 		param2py.b = 1;
 		param2py.B = 1;
 		param2py.h = 1;
