@@ -5,11 +5,11 @@
 //           Common platform independent code.
 // Language: C
 // Date:     10-May-2014
-// Ver:      24-Sep-2017.
+// Ver:      19-Jun-2018.
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2017    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2018    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -32,11 +32,13 @@
 
 #include "Python.h"
 
+#include "simddefs.h"
 #ifdef AF_HASSIMD
 #include "findindex_simd_x86.h"
 #endif
+#include "arrayparams_base.h"
+#include "arrayops.h"
 
-#include "arrayfunc.h"
 #include "arrayerrs.h"
 
 /*--------------------------------------------------------------------------- */
@@ -68,7 +70,7 @@ Py_ssize_t findindex_signed_char(signed int opcode, Py_ssize_t arraylen, signed
 #endif
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -77,7 +79,7 @@ Py_ssize_t findindex_signed_char(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -86,7 +88,7 @@ Py_ssize_t findindex_signed_char(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -95,7 +97,7 @@ Py_ssize_t findindex_signed_char(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -104,7 +106,7 @@ Py_ssize_t findindex_signed_char(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -113,7 +115,7 @@ Py_ssize_t findindex_signed_char(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -144,7 +146,7 @@ Py_ssize_t findindex_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsig
 	Py_ssize_t index; 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -153,7 +155,7 @@ Py_ssize_t findindex_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -162,7 +164,7 @@ Py_ssize_t findindex_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -171,7 +173,7 @@ Py_ssize_t findindex_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -180,7 +182,7 @@ Py_ssize_t findindex_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -189,7 +191,7 @@ Py_ssize_t findindex_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -228,7 +230,7 @@ Py_ssize_t findindex_signed_short(signed int opcode, Py_ssize_t arraylen, signed
 #endif
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -237,7 +239,7 @@ Py_ssize_t findindex_signed_short(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -246,7 +248,7 @@ Py_ssize_t findindex_signed_short(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -255,7 +257,7 @@ Py_ssize_t findindex_signed_short(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -264,7 +266,7 @@ Py_ssize_t findindex_signed_short(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -273,7 +275,7 @@ Py_ssize_t findindex_signed_short(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -304,7 +306,7 @@ Py_ssize_t findindex_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsi
 	Py_ssize_t index; 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -313,7 +315,7 @@ Py_ssize_t findindex_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsi
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -322,7 +324,7 @@ Py_ssize_t findindex_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsi
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -331,7 +333,7 @@ Py_ssize_t findindex_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsi
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -340,7 +342,7 @@ Py_ssize_t findindex_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsi
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -349,7 +351,7 @@ Py_ssize_t findindex_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsi
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -388,7 +390,7 @@ Py_ssize_t findindex_signed_int(signed int opcode, Py_ssize_t arraylen, signed i
 #endif
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -397,7 +399,7 @@ Py_ssize_t findindex_signed_int(signed int opcode, Py_ssize_t arraylen, signed i
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -406,7 +408,7 @@ Py_ssize_t findindex_signed_int(signed int opcode, Py_ssize_t arraylen, signed i
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -415,7 +417,7 @@ Py_ssize_t findindex_signed_int(signed int opcode, Py_ssize_t arraylen, signed i
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -424,7 +426,7 @@ Py_ssize_t findindex_signed_int(signed int opcode, Py_ssize_t arraylen, signed i
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -433,7 +435,7 @@ Py_ssize_t findindex_signed_int(signed int opcode, Py_ssize_t arraylen, signed i
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -464,7 +466,7 @@ Py_ssize_t findindex_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsign
 	Py_ssize_t index; 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -473,7 +475,7 @@ Py_ssize_t findindex_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsign
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -482,7 +484,7 @@ Py_ssize_t findindex_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsign
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -491,7 +493,7 @@ Py_ssize_t findindex_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsign
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -500,7 +502,7 @@ Py_ssize_t findindex_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsign
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -509,7 +511,7 @@ Py_ssize_t findindex_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsign
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -540,7 +542,7 @@ Py_ssize_t findindex_signed_long(signed int opcode, Py_ssize_t arraylen, signed
 	Py_ssize_t index; 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -549,7 +551,7 @@ Py_ssize_t findindex_signed_long(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -558,7 +560,7 @@ Py_ssize_t findindex_signed_long(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -567,7 +569,7 @@ Py_ssize_t findindex_signed_long(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -576,7 +578,7 @@ Py_ssize_t findindex_signed_long(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -585,7 +587,7 @@ Py_ssize_t findindex_signed_long(signed int opcode, Py_ssize_t arraylen, signed
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -616,7 +618,7 @@ Py_ssize_t findindex_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsig
 	Py_ssize_t index; 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -625,7 +627,7 @@ Py_ssize_t findindex_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -634,7 +636,7 @@ Py_ssize_t findindex_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -643,7 +645,7 @@ Py_ssize_t findindex_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -652,7 +654,7 @@ Py_ssize_t findindex_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -661,7 +663,7 @@ Py_ssize_t findindex_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsig
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -692,7 +694,7 @@ Py_ssize_t findindex_signed_long_long(signed int opcode, Py_ssize_t arraylen, si
 	Py_ssize_t index; 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -701,7 +703,7 @@ Py_ssize_t findindex_signed_long_long(signed int opcode, Py_ssize_t arraylen, si
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -710,7 +712,7 @@ Py_ssize_t findindex_signed_long_long(signed int opcode, Py_ssize_t arraylen, si
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -719,7 +721,7 @@ Py_ssize_t findindex_signed_long_long(signed int opcode, Py_ssize_t arraylen, si
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -728,7 +730,7 @@ Py_ssize_t findindex_signed_long_long(signed int opcode, Py_ssize_t arraylen, si
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -737,7 +739,7 @@ Py_ssize_t findindex_signed_long_long(signed int opcode, Py_ssize_t arraylen, si
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -768,7 +770,7 @@ Py_ssize_t findindex_unsigned_long_long(signed int opcode, Py_ssize_t arraylen,
 	Py_ssize_t index; 
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -777,7 +779,7 @@ Py_ssize_t findindex_unsigned_long_long(signed int opcode, Py_ssize_t arraylen,
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -786,7 +788,7 @@ Py_ssize_t findindex_unsigned_long_long(signed int opcode, Py_ssize_t arraylen,
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -795,7 +797,7 @@ Py_ssize_t findindex_unsigned_long_long(signed int opcode, Py_ssize_t arraylen,
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -804,7 +806,7 @@ Py_ssize_t findindex_unsigned_long_long(signed int opcode, Py_ssize_t arraylen,
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -813,7 +815,7 @@ Py_ssize_t findindex_unsigned_long_long(signed int opcode, Py_ssize_t arraylen,
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -852,7 +854,7 @@ Py_ssize_t findindex_float(signed int opcode, Py_ssize_t arraylen, float *data,
 #endif
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -861,7 +863,7 @@ Py_ssize_t findindex_float(signed int opcode, Py_ssize_t arraylen, float *data,
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -870,7 +872,7 @@ Py_ssize_t findindex_float(signed int opcode, Py_ssize_t arraylen, float *data,
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -879,7 +881,7 @@ Py_ssize_t findindex_float(signed int opcode, Py_ssize_t arraylen, float *data,
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -888,7 +890,7 @@ Py_ssize_t findindex_float(signed int opcode, Py_ssize_t arraylen, float *data,
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -897,7 +899,7 @@ Py_ssize_t findindex_float(signed int opcode, Py_ssize_t arraylen, float *data,
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
@@ -936,7 +938,7 @@ Py_ssize_t findindex_double(signed int opcode, Py_ssize_t arraylen, double *data
 #endif
 
 	switch(opcode) {
-	// af_eq
+	// AF_EQ
 	case OP_AF_EQ: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] == param1) {
@@ -945,7 +947,7 @@ Py_ssize_t findindex_double(signed int opcode, Py_ssize_t arraylen, double *data
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gt
+	// AF_GT
 	case OP_AF_GT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] > param1) {
@@ -954,7 +956,7 @@ Py_ssize_t findindex_double(signed int opcode, Py_ssize_t arraylen, double *data
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_gte
+	// AF_GTE
 	case OP_AF_GTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] >= param1) {
@@ -963,7 +965,7 @@ Py_ssize_t findindex_double(signed int opcode, Py_ssize_t arraylen, double *data
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lt
+	// AF_LT
 	case OP_AF_LT: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] < param1) {
@@ -972,7 +974,7 @@ Py_ssize_t findindex_double(signed int opcode, Py_ssize_t arraylen, double *data
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_lte
+	// AF_LTE
 	case OP_AF_LTE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] <= param1) {
@@ -981,7 +983,7 @@ Py_ssize_t findindex_double(signed int opcode, Py_ssize_t arraylen, double *data
 		}
 		return ARR_ERR_NOTFOUND;
 	}
-	// af_ne
+	// AF_NE
 	case OP_AF_NE: {
 		for(index = 0; index < arraylen; index++) {
 			if (data[index] != param1) {
