@@ -5,11 +5,11 @@
 //           This file provides an SIMD version of the functions.
 // Language: C
 // Date:     10-May-2017
-// Ver:      24-Sep-2017.
+// Ver:      19-Jun-2018.
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2017    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2018    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -32,7 +32,9 @@
 
 #include "Python.h"
 
-#include "arrayfunc.h"
+#include "simddefs.h"
+#include "arrayops.h"
+
 #include "arrayerrs.h"
 
 /*--------------------------------------------------------------------------- */
@@ -75,7 +77,7 @@ Py_ssize_t findindex_signed_char_simd(signed int opcode, Py_ssize_t arraylen, si
 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
@@ -101,7 +103,7 @@ Py_ssize_t findindex_signed_char_simd(signed int opcode, Py_ssize_t arraylen, si
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
@@ -127,7 +129,7 @@ Py_ssize_t findindex_signed_char_simd(signed int opcode, Py_ssize_t arraylen, si
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
@@ -154,7 +156,7 @@ Py_ssize_t findindex_signed_char_simd(signed int opcode, Py_ssize_t arraylen, si
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
@@ -181,7 +183,7 @@ Py_ssize_t findindex_signed_char_simd(signed int opcode, Py_ssize_t arraylen, si
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
@@ -207,7 +209,7 @@ Py_ssize_t findindex_signed_char_simd(signed int opcode, Py_ssize_t arraylen, si
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += CHARSIMDSIZE) {
@@ -275,7 +277,7 @@ Py_ssize_t findindex_signed_short_simd(signed int opcode, Py_ssize_t arraylen, s
 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
@@ -301,7 +303,7 @@ Py_ssize_t findindex_signed_short_simd(signed int opcode, Py_ssize_t arraylen, s
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
@@ -327,7 +329,7 @@ Py_ssize_t findindex_signed_short_simd(signed int opcode, Py_ssize_t arraylen, s
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
@@ -354,7 +356,7 @@ Py_ssize_t findindex_signed_short_simd(signed int opcode, Py_ssize_t arraylen, s
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
@@ -381,7 +383,7 @@ Py_ssize_t findindex_signed_short_simd(signed int opcode, Py_ssize_t arraylen, s
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
@@ -407,7 +409,7 @@ Py_ssize_t findindex_signed_short_simd(signed int opcode, Py_ssize_t arraylen, s
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += SHORTSIMDSIZE) {
@@ -475,7 +477,7 @@ Py_ssize_t findindex_signed_int_simd(signed int opcode, Py_ssize_t arraylen, sig
 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
@@ -501,7 +503,7 @@ Py_ssize_t findindex_signed_int_simd(signed int opcode, Py_ssize_t arraylen, sig
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
@@ -527,7 +529,7 @@ Py_ssize_t findindex_signed_int_simd(signed int opcode, Py_ssize_t arraylen, sig
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
@@ -554,7 +556,7 @@ Py_ssize_t findindex_signed_int_simd(signed int opcode, Py_ssize_t arraylen, sig
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
@@ -581,7 +583,7 @@ Py_ssize_t findindex_signed_int_simd(signed int opcode, Py_ssize_t arraylen, sig
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
@@ -607,7 +609,7 @@ Py_ssize_t findindex_signed_int_simd(signed int opcode, Py_ssize_t arraylen, sig
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += INTSIMDSIZE) {
@@ -675,7 +677,7 @@ Py_ssize_t findindex_float_simd(signed int opcode, Py_ssize_t arraylen, float *d
 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
@@ -701,7 +703,7 @@ Py_ssize_t findindex_float_simd(signed int opcode, Py_ssize_t arraylen, float *d
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
@@ -727,7 +729,7 @@ Py_ssize_t findindex_float_simd(signed int opcode, Py_ssize_t arraylen, float *d
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
@@ -753,7 +755,7 @@ Py_ssize_t findindex_float_simd(signed int opcode, Py_ssize_t arraylen, float *d
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
@@ -779,7 +781,7 @@ Py_ssize_t findindex_float_simd(signed int opcode, Py_ssize_t arraylen, float *d
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
@@ -805,7 +807,7 @@ Py_ssize_t findindex_float_simd(signed int opcode, Py_ssize_t arraylen, float *d
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += FLOATSIMDSIZE) {
@@ -873,7 +875,7 @@ Py_ssize_t findindex_double_simd(signed int opcode, Py_ssize_t arraylen, double
 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
@@ -899,7 +901,7 @@ Py_ssize_t findindex_double_simd(signed int opcode, Py_ssize_t arraylen, double
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
@@ -925,7 +927,7 @@ Py_ssize_t findindex_double_simd(signed int opcode, Py_ssize_t arraylen, double
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
@@ -951,7 +953,7 @@ Py_ssize_t findindex_double_simd(signed int opcode, Py_ssize_t arraylen, double
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
@@ -977,7 +979,7 @@ Py_ssize_t findindex_double_simd(signed int opcode, Py_ssize_t arraylen, double
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
@@ -1003,7 +1005,7 @@ Py_ssize_t findindex_double_simd(signed int opcode, Py_ssize_t arraylen, double
 
 		return ARR_ERR_NOTFOUND;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			// Use SIMD.
 			for(index = 0; index < alignedlength; index += DOUBLESIMDSIZE) {
