@@ -5,11 +5,11 @@
 //           Common platform independent code.
 // Language: C
 // Date:     10-May-2014
-// Ver:      24-Sep-2017.
+// Ver:      19-Jun-2018.
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2017    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2018    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -32,7 +32,9 @@
 
 #include "Python.h"
 
-#include "arrayfunc.h"
+#include "arrayparams_base.h"
+#include "arrayops.h"
+
 #include "arrayerrs.h"
 
 /*--------------------------------------------------------------------------- */
@@ -56,7 +58,7 @@ Py_ssize_t takewhile_signed_char(signed int opcode, Py_ssize_t arraylen, signed
 	Py_ssize_t index; 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] == param1)) {
@@ -66,7 +68,7 @@ Py_ssize_t takewhile_signed_char(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] > param1)) {
@@ -76,7 +78,7 @@ Py_ssize_t takewhile_signed_char(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] >= param1)) {
@@ -86,7 +88,7 @@ Py_ssize_t takewhile_signed_char(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] < param1)) {
@@ -96,7 +98,7 @@ Py_ssize_t takewhile_signed_char(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] <= param1)) {
@@ -106,7 +108,7 @@ Py_ssize_t takewhile_signed_char(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] != param1)) {
@@ -137,7 +139,7 @@ Py_ssize_t takewhile_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsig
 	Py_ssize_t index; 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] == param1)) {
@@ -147,7 +149,7 @@ Py_ssize_t takewhile_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsig
 			}
 			return index;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] > param1)) {
@@ -157,7 +159,7 @@ Py_ssize_t takewhile_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsig
 			}
 			return index;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] >= param1)) {
@@ -167,7 +169,7 @@ Py_ssize_t takewhile_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsig
 			}
 			return index;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] < param1)) {
@@ -177,7 +179,7 @@ Py_ssize_t takewhile_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsig
 			}
 			return index;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] <= param1)) {
@@ -187,7 +189,7 @@ Py_ssize_t takewhile_unsigned_char(signed int opcode, Py_ssize_t arraylen, unsig
 			}
 			return index;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] != param1)) {
@@ -218,7 +220,7 @@ Py_ssize_t takewhile_signed_short(signed int opcode, Py_ssize_t arraylen, signed
 	Py_ssize_t index; 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] == param1)) {
@@ -228,7 +230,7 @@ Py_ssize_t takewhile_signed_short(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] > param1)) {
@@ -238,7 +240,7 @@ Py_ssize_t takewhile_signed_short(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] >= param1)) {
@@ -248,7 +250,7 @@ Py_ssize_t takewhile_signed_short(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] < param1)) {
@@ -258,7 +260,7 @@ Py_ssize_t takewhile_signed_short(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] <= param1)) {
@@ -268,7 +270,7 @@ Py_ssize_t takewhile_signed_short(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] != param1)) {
@@ -299,7 +301,7 @@ Py_ssize_t takewhile_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsi
 	Py_ssize_t index; 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] == param1)) {
@@ -309,7 +311,7 @@ Py_ssize_t takewhile_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsi
 			}
 			return index;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] > param1)) {
@@ -319,7 +321,7 @@ Py_ssize_t takewhile_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsi
 			}
 			return index;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] >= param1)) {
@@ -329,7 +331,7 @@ Py_ssize_t takewhile_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsi
 			}
 			return index;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] < param1)) {
@@ -339,7 +341,7 @@ Py_ssize_t takewhile_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsi
 			}
 			return index;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] <= param1)) {
@@ -349,7 +351,7 @@ Py_ssize_t takewhile_unsigned_short(signed int opcode, Py_ssize_t arraylen, unsi
 			}
 			return index;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] != param1)) {
@@ -380,7 +382,7 @@ Py_ssize_t takewhile_signed_int(signed int opcode, Py_ssize_t arraylen, signed i
 	Py_ssize_t index; 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] == param1)) {
@@ -390,7 +392,7 @@ Py_ssize_t takewhile_signed_int(signed int opcode, Py_ssize_t arraylen, signed i
 			}
 			return index;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] > param1)) {
@@ -400,7 +402,7 @@ Py_ssize_t takewhile_signed_int(signed int opcode, Py_ssize_t arraylen, signed i
 			}
 			return index;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] >= param1)) {
@@ -410,7 +412,7 @@ Py_ssize_t takewhile_signed_int(signed int opcode, Py_ssize_t arraylen, signed i
 			}
 			return index;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] < param1)) {
@@ -420,7 +422,7 @@ Py_ssize_t takewhile_signed_int(signed int opcode, Py_ssize_t arraylen, signed i
 			}
 			return index;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] <= param1)) {
@@ -430,7 +432,7 @@ Py_ssize_t takewhile_signed_int(signed int opcode, Py_ssize_t arraylen, signed i
 			}
 			return index;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] != param1)) {
@@ -461,7 +463,7 @@ Py_ssize_t takewhile_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsign
 	Py_ssize_t index; 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] == param1)) {
@@ -471,7 +473,7 @@ Py_ssize_t takewhile_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsign
 			}
 			return index;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] > param1)) {
@@ -481,7 +483,7 @@ Py_ssize_t takewhile_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsign
 			}
 			return index;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] >= param1)) {
@@ -491,7 +493,7 @@ Py_ssize_t takewhile_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsign
 			}
 			return index;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] < param1)) {
@@ -501,7 +503,7 @@ Py_ssize_t takewhile_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsign
 			}
 			return index;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] <= param1)) {
@@ -511,7 +513,7 @@ Py_ssize_t takewhile_unsigned_int(signed int opcode, Py_ssize_t arraylen, unsign
 			}
 			return index;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] != param1)) {
@@ -542,7 +544,7 @@ Py_ssize_t takewhile_signed_long(signed int opcode, Py_ssize_t arraylen, signed
 	Py_ssize_t index; 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] == param1)) {
@@ -552,7 +554,7 @@ Py_ssize_t takewhile_signed_long(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] > param1)) {
@@ -562,7 +564,7 @@ Py_ssize_t takewhile_signed_long(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] >= param1)) {
@@ -572,7 +574,7 @@ Py_ssize_t takewhile_signed_long(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] < param1)) {
@@ -582,7 +584,7 @@ Py_ssize_t takewhile_signed_long(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] <= param1)) {
@@ -592,7 +594,7 @@ Py_ssize_t takewhile_signed_long(signed int opcode, Py_ssize_t arraylen, signed
 			}
 			return index;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] != param1)) {
@@ -623,7 +625,7 @@ Py_ssize_t takewhile_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsig
 	Py_ssize_t index; 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] == param1)) {
@@ -633,7 +635,7 @@ Py_ssize_t takewhile_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsig
 			}
 			return index;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] > param1)) {
@@ -643,7 +645,7 @@ Py_ssize_t takewhile_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsig
 			}
 			return index;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] >= param1)) {
@@ -653,7 +655,7 @@ Py_ssize_t takewhile_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsig
 			}
 			return index;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] < param1)) {
@@ -663,7 +665,7 @@ Py_ssize_t takewhile_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsig
 			}
 			return index;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] <= param1)) {
@@ -673,7 +675,7 @@ Py_ssize_t takewhile_unsigned_long(signed int opcode, Py_ssize_t arraylen, unsig
 			}
 			return index;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] != param1)) {
@@ -704,7 +706,7 @@ Py_ssize_t takewhile_signed_long_long(signed int opcode, Py_ssize_t arraylen, si
 	Py_ssize_t index; 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] == param1)) {
@@ -714,7 +716,7 @@ Py_ssize_t takewhile_signed_long_long(signed int opcode, Py_ssize_t arraylen, si
 			}
 			return index;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] > param1)) {
@@ -724,7 +726,7 @@ Py_ssize_t takewhile_signed_long_long(signed int opcode, Py_ssize_t arraylen, si
 			}
 			return index;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] >= param1)) {
@@ -734,7 +736,7 @@ Py_ssize_t takewhile_signed_long_long(signed int opcode, Py_ssize_t arraylen, si
 			}
 			return index;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] < param1)) {
@@ -744,7 +746,7 @@ Py_ssize_t takewhile_signed_long_long(signed int opcode, Py_ssize_t arraylen, si
 			}
 			return index;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] <= param1)) {
@@ -754,7 +756,7 @@ Py_ssize_t takewhile_signed_long_long(signed int opcode, Py_ssize_t arraylen, si
 			}
 			return index;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] != param1)) {
@@ -785,7 +787,7 @@ Py_ssize_t takewhile_unsigned_long_long(signed int opcode, Py_ssize_t arraylen,
 	Py_ssize_t index; 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] == param1)) {
@@ -795,7 +797,7 @@ Py_ssize_t takewhile_unsigned_long_long(signed int opcode, Py_ssize_t arraylen,
 			}
 			return index;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] > param1)) {
@@ -805,7 +807,7 @@ Py_ssize_t takewhile_unsigned_long_long(signed int opcode, Py_ssize_t arraylen,
 			}
 			return index;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] >= param1)) {
@@ -815,7 +817,7 @@ Py_ssize_t takewhile_unsigned_long_long(signed int opcode, Py_ssize_t arraylen,
 			}
 			return index;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] < param1)) {
@@ -825,7 +827,7 @@ Py_ssize_t takewhile_unsigned_long_long(signed int opcode, Py_ssize_t arraylen,
 			}
 			return index;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] <= param1)) {
@@ -835,7 +837,7 @@ Py_ssize_t takewhile_unsigned_long_long(signed int opcode, Py_ssize_t arraylen,
 			}
 			return index;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] != param1)) {
@@ -866,7 +868,7 @@ Py_ssize_t takewhile_float(signed int opcode, Py_ssize_t arraylen, float *data,
 	Py_ssize_t index; 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] == param1)) {
@@ -876,7 +878,7 @@ Py_ssize_t takewhile_float(signed int opcode, Py_ssize_t arraylen, float *data,
 			}
 			return index;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] > param1)) {
@@ -886,7 +888,7 @@ Py_ssize_t takewhile_float(signed int opcode, Py_ssize_t arraylen, float *data,
 			}
 			return index;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] >= param1)) {
@@ -896,7 +898,7 @@ Py_ssize_t takewhile_float(signed int opcode, Py_ssize_t arraylen, float *data,
 			}
 			return index;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] < param1)) {
@@ -906,7 +908,7 @@ Py_ssize_t takewhile_float(signed int opcode, Py_ssize_t arraylen, float *data,
 			}
 			return index;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] <= param1)) {
@@ -916,7 +918,7 @@ Py_ssize_t takewhile_float(signed int opcode, Py_ssize_t arraylen, float *data,
 			}
 			return index;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] != param1)) {
@@ -947,7 +949,7 @@ Py_ssize_t takewhile_double(signed int opcode, Py_ssize_t arraylen, double *data
 	Py_ssize_t index; 
 
 	switch(opcode) {
-		// af_eq
+		// AF_EQ
 		case OP_AF_EQ: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] == param1)) {
@@ -957,7 +959,7 @@ Py_ssize_t takewhile_double(signed int opcode, Py_ssize_t arraylen, double *data
 			}
 			return index;
 		}
-		// af_gt
+		// AF_GT
 		case OP_AF_GT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] > param1)) {
@@ -967,7 +969,7 @@ Py_ssize_t takewhile_double(signed int opcode, Py_ssize_t arraylen, double *data
 			}
 			return index;
 		}
-		// af_gte
+		// AF_GTE
 		case OP_AF_GTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] >= param1)) {
@@ -977,7 +979,7 @@ Py_ssize_t takewhile_double(signed int opcode, Py_ssize_t arraylen, double *data
 			}
 			return index;
 		}
-		// af_lt
+		// AF_LT
 		case OP_AF_LT: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] < param1)) {
@@ -987,7 +989,7 @@ Py_ssize_t takewhile_double(signed int opcode, Py_ssize_t arraylen, double *data
 			}
 			return index;
 		}
-		// af_lte
+		// AF_LTE
 		case OP_AF_LTE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] <= param1)) {
@@ -997,7 +999,7 @@ Py_ssize_t takewhile_double(signed int opcode, Py_ssize_t arraylen, double *data
 			}
 			return index;
 		}
-		// af_ne
+		// AF_NE
 		case OP_AF_NE: {
 			for(index = 0; index < arraylen; index++) {
 				if (!(data[index] != param1)) {
